@@ -6,8 +6,14 @@ pub enum Error {
     ReqwestError(#[from] reqwest::Error),
     #[error(transparent)]
     SerdeJsonError(#[from] serde_json::Error),
-    #[error("{0}")]
-    ApiError(String),
+    #[error(transparent)]
+    ApiError(#[from] ApiError),
     #[error("Unexpected data from server {0}")]
     UnexpectedData(String)
-}
\ No newline at end of file
+}
+
+#[derive(Debug, thiserror::Error)]
+#[error("{0}")]
+pub struct ApiError(pub String);
+
+pub struct NoError();
\ No newline at end of file
